function [DYE] = estimate_DYE(dat,PAR,xcorrect,name,rblock,cblock);
%
% USAGE: [DYE] = estimate_DYE(dat,PAR,xcorrect,var,rblock,cblock);
% PAR has MASS header info and dat has radiance data in the form of a matlab.io file
% or in structures w/ fields:
% PAR.Wavelength      = center of spectral bins;
% PAR.Wavelencth_width= bin width of band
% dat.rad             = spectral radiance
% xcorrect            = logical; 1 == apply cross-shore correction
% name                = string if 'rad' is not default variable
% rblock              = row-vector indices on which to estimate D
% cblock              = column-vector indices ...

if exist('name','var')
%     dum = struct([]);
%     eval(['dum(1).rad = dat.',name,';'])
%     dat = dum;
    dum = ['dat.',name];
    info = whos(dat,name);
else 
    dum = ['dat.rad'];
    info = whos(dat,'rad');
end
    nD = numel(info.size);

if ~exist('xcorrect','var')
    xcorrect=1;
end
%
L  = PAR.Wavelength;
dL = PAR.Wavelength_width;
if nD<3, disp(['empty radiance field: ',PAR.rawfile]), DYE=[]; return, end
nc=info.size(1);
na=info.size(2);
nL=info.size(3);
%
% bands for emission/absorption ratio 
% indices taken from load_hyper_emit_absorb_CSIDE.m
iabsorb = [34:36];
iemit = [41:42];    
%
if ~exist('rblock','var')
   rblock = 1:nc;
   cblock = 1:na;
else
    nc = length(rblock);
    na = length(cblock);
end
%
nLa = length(iabsorb);
nLe = length(iemit);
dLabsorb = repmat( reshape(dL(iabsorb),1,1,nLa), nc,na,1);
dLemit   = repmat( reshape(dL(iemit)  ,1,1,nLe), nc,na,1);
%
if nc*na*nLa>=1.5e9 
    disp('transect is too long...DYE=[];')
    DYE=[];
    return
end
% if nL*na*nc
%
% ineutral = [73:74];
%
% nabsorb = length(iabsorb);
% nemit   = length(iemit);
% dLL = repmat( reshape(dL,1,1,nL), nc, na, 1 );
% R = sum( dat.rad.*dLL,3);
% Rmax = nanmax(R(:));
% Ra    = sum( dLL(:,:,iabsorb).*eval([dum,'(rblock,cblock,iabsorb)'])  ,3)./sum(dLL(:,:,iabsorb) ,3);
% Re    = sum( dLL(:,:,iemit  ).*eval([dum,'(rblock,cblock,iemit  )'])  ,3)./sum(dLL(:,:,iemit)   ,3);
Ra    = sum( dLabsorb.*eval([dum,'(rblock,cblock,iabsorb)'])  ,3)./sum(dLabsorb ,3);
Re    = sum(   dLemit.*eval([dum,'(rblock,cblock,iemit  )'])  ,3)./sum(dLemit   ,3);
%
RATIO = Re./Ra;
%
% estimate slope/intercept using full data (all releases)
% [mdye, bdye] = fit_hyper_to_ski_full_spectrum([]);
% [mdye, bdye] = fit_hyper_to_ski([]);
mdye =8.367631998375321 ;% full spectrum==8.133573850517337;
bdye =-5.870693868357249;% full_spectrum==-5.711935078390150;
%
%
DYE = mdye*RATIO+bdye;
%
if xcorrect
% apply cross-shore correction
xcorrect_file = '/home/dgrimes/CSIDE/R2/mat_data/background_xshore_DYE.mat';
if exist(xcorrect_file,'file')
load(xcorrect_file,'Dbar')
nr = size(Dbar,1);
    if nc~=nr, 
        disp('issue w/ background cross-shore dye signal input grid does not match DYE(nr,nc)'),
        load(xcorrect_file,'c')
        cin = dat.c;
        Dbar= interp1(c,Dbar,cin);
    end
else
    disp('cross-shore correction file does not exist...')
    Dbar=zeros(nc,1);
end
else
    Dbar=zeros(nc,1);
end
%
DYE = DYE-Dbar*ones(1,na);
%
% apply shoreline / integrated radiance mask
% TBD
%
DYE(DYE<0)=0;

