function [Dsz,Dis,y,t,Co,Fo,Pe] = run_SZ_IS_box_model_v2(dy,Vsz,Vis,Lsz,Lis,Hsz,Ksz,Kyy,Kis,KyyIS,plotter);
%
% USAGE: [Dsz,Dis,y,t,Co,Fo,Pe] = run_SZ_IS_box_model_v2(dy,Vsz,Vis,Lsz,Lis,Hsz,Ksz,Kyy,Kis,KyyIS,plotter);
%
% script to setup and run tracer advec, diff, reaction eq. 
% based on FF code in /home/ffeddersen/CSIDE/shoreline_study/...
%
if isempty(plotter)
    plotter=0;
end
%
%y = [-0.5e3:8:8e3];
y = [-4e3:dy:8e3];
%dy = y(2)-y(1);
%
% source of dye tracer
totDvol = 113.6*1e-3;% Liters --> m^3
totDconc= 0.2149    ;% fraction dye
totDppb = totDconc*1e9;% ppb dye
totDmass= totDvol*totDppb;% m^3 ppb
totDtime = 3.84*3600;% hours-->seconds
                     % Lsz = 100;% SZ width
% Lis = (sqrt(2)-1)*Lsz;% IS width
% Hsz = 2;  % depth of wave breaking
Asz = 1/2*Lsz*Hsz;% sz area
Ais = Lis*Hsz + Lis*Lis*Hsz/Lsz/2;% is area
Ly  = round(Vsz*totDtime);% alongshore width of initial condition
szDconc = totDmass/(Ly*Asz);% mean concentration of SZ in ppb
                            %
disp(sprintf('intial SZ dye concentration: %2.1f ppb',szDconc))

Q = szDconc;
% iQ = find(y>=0,1,'first')+[0:round(Ly/dy)-1]';
iQ = find(y>=0,1,'first');

% use Dmax decay length scale to estimate Ksz...
% based on exponential (too short)
% y_decay = ceil(1/0.001067376231842);
%
% based on Dmax~D0(y/y0)^a; a = -1.054
% D0 ~ 96656;
% Aplume = totDmass/D0
% y_decay = round(10^(-3/-1.054*1+1/-1.054*log10(1/4)));
% Ksz  = 6e-5;%;round(Vsz/y_decay*1e5);
%
% FF estimate: "what should Ksz be?"
% for steady  Ksz = V/y_decay_scale  where y_decay_scale = 8000 m.  let V =0.1?
% y_decay = 10000;
% Vsz0 = 0.1;
% Ksz = Vsz0/y_decay;

% Co = max(V)*dt/dy
%
dt_max  = dy/Vsz/2
dt = min(floor(dt_max), floor(dy^2./(4*Kyy)))
if dt>30
dt=30;
end
% 
Co = dt*Vsz/dy
Fo  = dt*Kyy/dy^2
Pe  = Co/Fo
%
% dt =0.01
T  = 31*3600;%24*3600;% hours
nt = ceil(T/dt);
%
t = 0:dt:(nt-1)*dt;
% have time-dependent release
Q = 0*t; 
Q(t/3600<=3.84)=totDmass/totDtime/Asz/dy;
% Ds      = solve_shoreline_dye_adv_DG(y,dt,Vsz*ones(nt,1),iQ,Q,Ksz,0, Kyy);
%[Ds]  = solve_shoreline_dye_adv_DG(y,dt,Vsz*ones(nt,1),iQ,Q,Ksz,0, Kyy);
% [Dsz,Dis]  = solve_SZ_IS_dye_adv_diff_wISlosses_and_diff_DG(y,dt,Vsz*ones(nt,1),Vis*ones(nt,1),iQ,Q,Ksz,0,Kyy,Asz/Ais,Kis,KyyIS);
[Dsz,Dis]  = solve_SZ_IS_dye_adv_diff_v2(y,dt,Vsz*ones(nt,1),Vis*ones(nt,1),iQ,Q,Ksz,0,Kyy,Asz/Ais,Kis,KyyIS);
% tday = t/86400+time_dnum(1);

% resample to nominal sample rate of 1 min
Nt = round(1*60./dt);
Dsz = Dsz(:,1:Nt:end);
Dis = Dis(:,1:Nt:end);
Q  = Q(1:Nt:end);
t  = t(1:Nt:end);


fout = get_box_model_file_varying_dy_and_KyyIS(dy,Vsz,Vis,Ksz,Kyy,Asz,Ais,Kis,KyyIS);
% 
% fout = sprintf('/home/dgrimes/CSIDE/R2/mat_data/surfzone_innershelf_DYE_dy_%03d_vSZ1e2_%03d_vIS1e2_%03d_Kd1e6_%03d_Kyy1e1_%03d_AszAis1e1_%02d_KdIS1e6_%03d.mat',round(dy),round(Vsz*100),round(Vis*100),round(Ksz*1e6),round(Kyy*10),round(Asz/Ais*10),round(Kis*1e6));
% 
save(fout,'Dsz','Dis','y','t','dt','Q','Ksz','Vsz','Vis','Lis','Lsz','Asz','Ais','Kis','Kyy','dy');

% ii = find(Ds<1e-16);
% Ds(ii) = 1e-16;
% VADV = struct('Ds',Ds,'y',y,'tday',tday,'dt',dt','Q',Q,'Kd',Kd,'V',V);
% 
% save DSHORE_ADV.mat VADV;

% return

if plotter

fig = figure;
set(fig,'PaperUnits','centimeters')
xSize = 16; ySize = 10;  %size of the figure to be generated
                             %xLeft = (21-xSize)/2; yTop = (30-ySize)/2;
set(fig,'PaperPosition',[0 0  xSize ySize])

%subplot('position',[0.1 0.3 0.85 0.6])
dye_range = 10.^[0 1];
dye_tick =  10.^[-1 0 1 2];
dye_bgcolor = 0.9*[1 1 1];
cm1= interp1([1;ceil(256/diff(dye_range));256],[25 85 180;255 255 255;252 15 220]/255,[1:256]);

imsc(y,t'/3600,(Dis)',cm1,dye_bgcolor,Dis'==0)
% imsc(y,t'/3600,(Dsz)',cm1,dye_bgcolor,Dsz'==0)
shading flat
caxis(dye_range)
ylabel('$\mathcal{T}_\mathrm{r}~\mathrm{[h]}$','interpreter','latex')
xlabel('$\tilde{y}~\mathrm{[m]}$','interpreter','latex')
str = sprintf('$K_\\mathrm{d} = %d {\\times} 10^{-6} $~[1/s], $K_{yy} = %1.2f$~[m$^2$/s], $A_\\mathrm{sz}/A_\\mathrm{is}=%1.1f$',Ksz*1e6,Kyy,Asz/Ais)
title(str,'interpreter','latex','fontsize',13)
c1=axes('position',[  0.85    0.65    0.017  0.162 ],'yaxislocation','left');
clr = [dye_range(1):diff(dye_range)/255:dye_range(2)];
imagesc(0,clr,reshape(cm1,256,1,3))
ylabel(c1,'$~~~~~~~\mathrm{[ppb]}$','interpreter','latex')
set(c1,'tickdir','out','xtick',[],'ydir','normal')

% subplot('position',[0.1 0.08 0.85 0.2])
% plot(tday,V)
% grid
% datetick('x','mmdd')
% ylabel('V (m/s)')

fout = sprintf('/home/dgrimes/CSIDE/R2/figures/surfzone_DYE_vSZ1e2_%03d_vIS1e2_%03d_Kd1e6_%03d_Kyy1e1_%03d_AszAis1e1_%02d.pdf',round(Vsz*100),round(Vis*100),round(Ksz*1e6),round(Kyy*10),round(Asz/Ais*10));

% fout = sprintf('/home/dgrimes/CSIDE/R2/figures/surfzone_DYE_v1e2_%03d_Kd1e6_%03d_Kyy1e1_%03d_AszAis1e1_%02d',round(Vsz*100),round(Kd*1e6),round(Kyy*10),round(Asz/Ais*10));

vecrast(fig,fout,1200,'bottom','pdf')
%%% mean stats

end
