function [ashore,cshore,xshoreline,yshoreline,bshoreline] = xytoac_v2(xin,yin,tin)
%
% USAGE: [ashore,cshore,xshoreline,yshoreline,bshoreline] = xytoac(xin,yin);
%
% make a coordinate system with x=0 at z=MSL or Z=0 shoreline,
% ashore = \tilde{y} with ashore>0 generally north
% cshore = \tilde{x} with cshore<0 generally west (offshore)

% load bathy xs ys Zs
% load('/data1/CSIDE/MASS/mat_data/CSIDEbathy_raw.mat');
% load('/home/dgrimes/CSIDE/R2/mat_data/CSIDEbathy_smooth.mat','xi','yi','Zi_smooth')
  load('/home/dgrimes/CSIDE/R2/mat_data/CSIDEbathy_smooth.mat','xi','yi','Zi_noJ_smooth')
  Zi=Zi_noJ_smooth; clear Zi_noJ_smooth;
%
if exist('tin','var')
    ztide = get_tidal_elevation_CSIDE(tin);
    Zi = Zi-ztide;
% mask estuary
%     figure, contourf(xi,yi,Zi,[-5:5]), hold on,
%     contour(xi,yi,Zi,[0 0],':r')
%     set(gca,'xlim',[-250 2000],'ylim',[-5e3 -250])
%     xy = ginput;
%     in = inpolygon(xi,yi,xy(:,1),xy(:,2));
%     save('/data1/CSIDE/MASS/mat_data/CSIDEbathy_smooth_points_in_estuary.mat','xy','in')
    load('/data1/CSIDE/MASS/mat_data/CSIDEbathy_smooth_points_in_estuary.mat')
    Zi(in) = 10;
else 
    ztide = 0;
    load('/data1/CSIDE/MASS/mat_data/CSIDEbathy_smooth_points_in_estuary.mat')
    Zi(in) = 10;
end

% new method of finding shoreline:
% 1) start nearest (x=0,y=0)
% 2) estimate where z=0 and denote this location as (xt=0,yt=0)
% 3) move N/S at 2~m increments along z=0

% 1) find origin
wtr=(Zi<=0 & xi>-5e3);
i0 = find( Zi<=0 & xi>-5e3);% pixels below MSL
[dist, i1] = min(sqrt(xi(i0).^2 + yi(i0).^2));% distance of water pixels to origin
[r1,c1] = ind2sub(size(Zi), i0(i1));% row column of the origin pixel
%
% get gradient for "tracing" shoreline
[dzdx,dzdy] = gradient(Zi/10);
dz = sqrt(dzdx.^2 + dzdy.^2);
% now extract placket neighboring [r1,c1] to find (x,y,z==0) ;
% start at origin, note that onshore is to right, hence [0 1] for columns
xx = xi(r1,c1+[0 1]);
zz = Zi(r1,c1+[0 1]);
bb = [ones(2,1) xx(:)]\zz(:);
%
x0 = xi(r1,c1)-Zi(r1,c1)/bb(2);
y0 = yi(r1,c1);
b0 = bb(2);
% 
% % alternative method
% ds = -Zi(r1,c1)/dz(r1,c1);
% dx = ds*dzdx(r1,c1)/dz(r1,c1);
% dy = ds*dzdy(r1,c1)/dz(r1,c1);
% x0v2=xi(r1,c1)+dx;
% y0v2=yi(r1,c1)+dy;
% %
% 
xs = nan(r1,1); xs(r1)=x0;
ys = xs;        ys(r1)=y0;
bs = xs;        bs(r1)=b0;
% xsv2= nan(r1,1); xsv2(r1)=x0v2;
% ysv2= xs;        ysv2(r1)=y0v2;
%
r  = r1;
c  = c1;
for ii=r1-1:-1:1
    iwtr=find(wtr(ii,:));
    xt=xs(ii+1)-10*dzdy(r,c)/dz(r,c);
    yt=ys(ii+1)-10*dzdx(r,c)/dz(r,c);
    %
    [dist,cnew] = min( sqrt((xi(ii,iwtr)-xt).^2 + (yi(ii,iwtr)-yt).^2) );
    % 
    r = ii;
    c = iwtr(cnew);
%     % distance of water pixels to origin
%     [dist, inew] = min(sqrt((xi(i0)-xt).^2+(yi(i0)-yt).^2));
%     % row column of the origin pixel
%     [r,c] = ind2sub(size(Zi), i0(inew));
%     %
%     if r~=ii, disp(['row \ne index: ii=',num2str(ii)]), end
    %
    %
    xx = xi(r,c+[0 1]);
    zz = Zi(r,c+[0 1]);
    bb = [ones(2,1) xx(:)]\zz(:);
    %
    xs(ii) = xi(r,c)-Zi(r,c)/bb(2);
    ys(ii) = yi(r,c);
    bs(ii) = bb(2);
    %
    % alternative method
%     ds = -Zi(r,c)/dz(r,c);
%     dx = ds*dzdx(r,c)/dz(r,c);
%     dy = ds*dzdy(r,c)/dz(r,c);
%     xsv2(ii)=xi(r,c)+dx;
%     ysv2(ii)=yi(r,c)+dy;
    %
    %
end
%
%
for ii=r1+1:size(Zi,1)
    iwtr=find(wtr(ii,:));
    xt=xs(ii-1)+10*dzdy(r,c)/dz(r,c);
    yt=ys(ii-1)+10*dzdx(r,c)/dz(r,c);
    %
    [dist,cnew] = min( sqrt((xi(ii,iwtr)-xt).^2 + (yi(ii,iwtr)-yt).^2) );
    % 
    r = ii;
    c = iwtr(cnew);
    %
    %
    xx = xi(r,c+[0 1]);
    zz = Zi(r,c+[0 1]);
    bb = [ones(2,1) xx(:)]\zz(:);
    %
    xs(ii) = xi(r,c)-Zi(r,c)/bb(2);
    ys(ii) = yi(r,c);
    bs(ii) = bb(2);
    %
end
%
%
% trim to be -2500m to 10500m
ikeep = find(ys>=-2500 & ys<=10500);
xp = xs(ikeep);
yp = ys(ikeep);
bp = bs(ikeep);
r1 = r1-ikeep(1)+1;
%
%
[nx,~] = size(xp);
%
%
% recall origin is near (r1,c1)
% generate vector of "alongshore" distance versus (xp,yp) 
aps = zeros(nx,1);
% shoreline vector starts at southern boundary 
% ii is list of indices starting at origin and going toward southern boundary
ii = r1:-1:1;
% alongshore distance between shoreline points
dx = gradient(xp(ii));
dy = gradient(yp(ii));
ds = sqrt(dx.^2+dy.^2);
%
% add up distances to current index
dum = cumsum(-ds);
aps(ii(2:end)) = dum(1:end-1);
% 
% now go from origin toward northern boundary
ii = r1:length(ikeep);%size(Zi,1);
%
dx = gradient(xp(ii));
dy = gradient(yp(ii));
ds = sqrt(dx.^2+dy.^2);
%
% add up distances to current index
dum = cumsum(ds);
aps(ii(2:end)) = dum(1:end-1);
%
% 
% % vectors are from north to south so
% % i = 1:iorigin are +y direction
% aps = zeros(iend-istart+1,1);
% % aps = nan(iend-istart+1,1);
% aps(iorigin) = 0;
% ii = [iorigin:-1:1];
% dx = gradient(xp(ii));
% dy = gradient(yps(ii));
% ds = sqrt(dx.^2+dy.^2);
% 
% % keyboard
% % for j = 1:numel(dx)-1
% %     aps(ii(j+1)) = aps(ii(j))+ds(j);
% % end
% 
% dum = cumsum(ds);
% aps(ii(2:end)) = dum(1:end-1);
% 
% % i = iorigin:end are -y
% ii = [iorigin:nxs];
% dx = gradient(xps(ii));
% dy = gradient(yps(ii));
% ds = sqrt(dx.^2+dy.^2);
% 
% % for j = 1:numel(dx)-1
% %     aps(ii(j)+1) = aps(ii(j))-ds(j);
% % end
% 
% dum = cumsum(-ds);
% aps(ii(2:end)) = dum(1:end-1);
%
% make monotonic
[aps,iuni] = unique(aps);
xp = xp(iuni);
yp = yp(iuni);
bp = bp(iuni);
% interpolate to 2 m alongshore resolution 
asamp = [max(aps):-2:min(aps)]';
Xsamp = interp1(aps,xp+i*yp,asamp,'linear');
Bsamp = interp1(aps,bp,asamp,'linear');
%
% smooth using ~100 m ashore filter
fin= 1/median(abs(diff(aps)));% about 1/10m
                              %
sample_freq = 1/2;% sample frequency is 2m
cutoff_freq = fin/100;% cutoff at 10 \times 10m\approx 100m
% frequency cutoff @ cutoff_freq w/ sample rate of saple_freq
Wn = 2.*cutoff_freq/sample_freq;% the 2.* makes cutoff_freq
                                % the highest resolvable 
                                % frequency
% order of filter 
n = 2;
%
% use butterworth filter (default is lowpass)
[a,b] = butter(n,Wn);
%
Xsampfilt = filtfilt(a,b,Xsamp);
%
xsamp = real(Xsampfilt);
ysamp = imag(Xsampfilt);
%
Bsampfilt = filtfilt(a,b,Bsamp);
%
% this is the slow part
if ~isempty(xin)
    for ii = 1:length(xin)
        [c_,ishore] = min(sqrt( (xin(ii)-xsamp).^2 + (yin(ii)-ysamp).^2));
        angle(ii) = atan2(yin(ii)-ysamp(ishore),...
                        -(xin(ii)-xsamp(ishore)));
        
        xdist = (xin(ii)-xsamp(ishore));
        ydist = (yin(ii)-ysamp(ishore));


        if yin(ii) > 4500
            if xdist<0
                c_sign = 1;
            elseif xdist>=0 & ydist<0
                c_sign = 1;
            else
                c_sign = -1;
            end
        else
            c_sign = -sign(xin(ii) - xsamp(ishore));
        end
        cshore(ii) = -c_sign*c_;
        ashore(ii) = asamp(ishore);
    end
else
    ashore = [];
    cshore = [];
end
%keyboard    
    ashore = ashore';
    cshore = cshore';
    xshoreline=xsamp;
    yshoreline=ysamp;
    bshoreline=Bsamp;

% test_xytoac = 1;
% if test_xytoac
% [~,~,xshore,yshore] = xytoac_imperialbeach([],[]);
% plot(xshore,yshore,'r.',xshoreline,yshoreline,'k.')
% set(gca,'xlim',[-4e3 500],'ylim',[-2.5e3 10.5e3])
% end

% estimate shoreline radius of curvature...
% keyboard
xs = xsamp;
ys = ysamp;
as = asamp;

zs = xs + sqrt(-1)*ys;
ds = abs(gradient(zs));

dx = gradient(xs)./ds;
dy = gradient(ys)./ds;
ddx= gradient(dx)./ds;
ddy= gradient(dy)./ds;

r = (dx.^2 + dy.^2).^(3/2)./abs(dx.*ddy - ddx.*dy);

% estimate mean curvature between [0 5km] in r2 coords (yR2\approx 1km);
ir = find(ys>=1e3 & ys<=8e3);
rmin = nanmin(r(ir));



